@@ -73,7 +73,7 @@ void Box_Data_List::fill_from_database()
       Glib::RefPtr<Gnome::Gda::Connection> connection = sharedconnection->get_gda_connection();
 
       Glib::ustring strWhereClausePiece;
-      if(m_strWhereClause.size())
+      if(!m_strWhereClause.empty())
         strWhereClausePiece = " WHERE " + m_strWhereClause;
 
       type_vecFields listFieldsToShow = get_fields_to_show();
@@ -191,7 +191,7 @@ void Box_Data_List::on_AddDel_user_added(const Gtk::TreeModel::iterator& row)
 {
   Gnome::Gda::Value primary_key_value;
 
-  const Glib::ustring& strPrimaryKeyName = get_PrimaryKey_Name();
+  const Glib::ustring& strPrimaryKeyName = get_primarykey_name();
   Field field;
   bool found = get_field(strPrimaryKeyName, field);
   if(!found)
@@ -252,21 +252,25 @@ void Box_Data_List::on_AddDel_user_reordered_columns()
   Document_Glom* pDoc = dynamic_cast<Document_Glom*>(get_document());
   if(pDoc)
   {
+    LayoutGroup group;
+    group.m_group_name = "others";
+    
     AddDel::type_vecStrings vec_field_names = m_AddDel.get_columns_order();
 
-    Document_Glom::type_mapFieldSequence mapFieldSequence;
     guint index = 0;
     for(AddDel::type_vecStrings::iterator iter = vec_field_names.begin(); iter != vec_field_names.end(); ++iter)
     {
       LayoutItem layout_item;
       layout_item.m_field_name = *iter;
       layout_item.m_sequence = index;
-      mapFieldSequence[index] = layout_item; 
+      group.m_map_items[index] = layout_item; 
       ++index;
     }
-  
-    pDoc->set_data_layout_list(m_strTableName, mapFieldSequence);
+
+    Document_Glom::type_mapLayoutGroupSequence mapGroups;
+    mapGroups[0] = group;
     
+    pDoc->set_data_layout_groups("list", m_strTableName, mapGroups);  
   }
 }
 
@@ -314,7 +318,7 @@ void Box_Data_List::on_AddDel_user_changed(const Gtk::TreeModel::iterator& row,
 
     Field field_primary_key;
 
-    bool found = get_field(get_PrimaryKey_Name(), field_primary_key);
+    bool found = get_field(get_primarykey_name(), field_primary_key);
     if(found && field_primary_key.get_field_info().get_auto_increment())
     {
       on_AddDel_user_added(row);
